----------------------------------------------------

---	This description starts one line down,
---			some indented text
---	And has a line in the middle, followed by trailing lines.
---
---	Double blank here
---
---	```lua
---	function test()
---		print("indentation")
---
---		do
---
---			print("more indented")
---		end
---	end
---	```
---
---
---	@class triple

--- not present in output
--[=[
	@class b8f83
]=]
--- some more text
--- @type hello x
--- @within b8f83

--- @within triple
--- @param eher efe -- fhef
function example() end
